@@ -32,10 +32,7 @@ def connect():
     database=stdata["database"]
     if "port" in stdata:
         stdata["port"]=int(stdata["port"])
-    try:
-        db.conn=pymysql.connect(**stdata)
-    except:
-        quit("connect error!")
+    db.conn=pymysql.connect(**stdata)
 
 def export(stdata,storidata):
     dbtt.export(stdata,storidata,dbdata)
